# Copyright 2023 Ross J. Duff MSc
# The copyright holder licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at

#   http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
"""python snippet: grab version info"""
from setuptools_scm import get_version
print(get_version(normalize=False))



# Copyright 2023 Ross J. Duff MSc
# The copyright holder licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at

#   http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
"""python template: check core metadata"""
import pathlib
import os
#
import tomli
# pylint: disable=consider-using-with
source = pathlib.Path(os.environ.get("MESON_SOURCE_ROOT", ".."))
project_file = open(source/"pyproject.toml", "rb")
pyproject_toml = tomli.load(project_file)
project_file.close()
core_metadata = pyproject_toml.get("project", {"optional_dependencies": {}})
print(core_metadata.get("optional_dependencies", {"todo": []}).get("@0@", "fail"))
